##  Relation Multiplicity
Relation multiplicity determines the number of fact sheets that can be linked on both ends of a relation. Once set, the multiplicity on custom relations cannot be changed. Similarly, the multiplicity on predefined relations cannot be changed.
The following relation multiplicities are available:
  * Many to many: Multiple fact sheets can link to multiple others. This multiplicity allows creating a complex network of relations.
  * One to many: A single fact sheet can link to multiple others. This highlights the importance of a single fact sheet that is relevant to numerous others.
  * Many to one: Multiple fact sheets can link to a single one. This multiplicity is the reverse of the One to many multiplicity.
  * One to one: One fact sheet directly links to only one other. It's a direct and exclusive connection between two fact sheets, indicating a unique relationship where changes to one may directly impact the other.
